@@ -4,9 +4,9 @@ from __future__ import unicode_literals
 import argparse
 import os
 import os.path
-import pkg_resources
 import sqlite3
-import sys
+
+import pkg_resources
 
 from git_code_debt import options
 from git_code_debt import write_logic
@@ -39,8 +39,6 @@ def populate_metric_ids(db, package_names, skip_defaults):
 
 
 def main(argv=None):
-    argv = argv if argv is not None else sys.argv[1:]
-
     parser = argparse.ArgumentParser(description='Set up schema')
     # optional
     options.add_skip_default_metrics(parser)
